@@ -590,7 +590,7 @@ go back to ((<Index>))
     # 整数型の場合は浮動小数型へ変換
     ary0 = self.integer? ? self.to_type(NArray::DFLOAT) : self
     NArrayMiss.reduction(@mask, min_count, dims, true, typecode) do |count_sum, count_accum|
-      var = ary0.sum(*dims)/count_sum
+      ary0.sum(*dims)/count_sum
     end
   end
   def stddev(*dims)
@@ -1509,7 +1509,7 @@ module NMMath
       NMMath.#{operator}(*x)
     end
     EOL
- end
+  end
 
 end
 
